==> plugin-android-3.1.1-sources.jar: com/zoyi/channel/plugin/android/model/rest/User.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.graphics.Color;

import com.zoyi.channel.plugin.android.model.interfaces.GuestEntity;
import com.zoyi.channel.plugin.android.model.interfaces.PersonEntity;
import com.zoyi.channel.plugin.android.model.interfaces.ProfileEntity;

import java.util.List;
import java.util.Map;

/**
 * Created by mika on 2017. 1. 16..
 */
public class User implements PersonEntity, GuestEntity {
  private String channelId;
  private String id;
  private String name;
  private String mobileNumber;
  private String avatarUrl;
  private Object meta;
  private Boolean named;
  private String locale;
  private String country;
  private String city;
  private String lastPageViewId;
  private Long pageViewsCount;
  private Long visitsCount;
  private Long createdAt;
  private Long updatedAt;
  private Long version;
  private String initial;
  private String color;
  private Map<String, Object> profile;
  private int alert;

  public String getId() {
    return id;
  }

  public String getName() {
    return name;
  }

  @Override
  public String getPersonType() {
    return this.getClass().getSimpleName();
  }

  @Override
  public int getBackgroundColor() {
    try {
      return Color.parseColor(color);
    } catch (Exception ex) {
    }
    return Color.BLACK;
  }

  @Override
  public int getTextColor() {
    return Color.WHITE;
  }

  @Override
  public String getAvatarUrl() {
    return avatarUrl;
  }

  @Override
  public String getInitial() {
    return initial;
  }

  @Override
  public boolean isHost() {
    return false;
  }

  public String getMobileNumber() {
    return mobileNumber;
  }

  public final static String CLASSNAME = "User";

  public Boolean isNamed() {
    return named;
  }

  public int getAlert() {
    return alert;
  }

  public Map<String, Object> getProfile() {
    return profile;
  }

  @Override
  public Object getProfileValue(String key) {
    return profile.get(key);
  }
}

==> plugin-android-3.1.5-sources.jar: com/zoyi/channel/plugin/android/model/rest/User.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.graphics.Color;

import com.zoyi.channel.plugin.android.Guest;
import com.zoyi.channel.plugin.android.model.interfaces.GuestEntity;
import com.zoyi.channel.plugin.android.model.interfaces.PersonEntity;
import com.zoyi.channel.plugin.android.model.interfaces.ProfileEntity;

import java.util.List;
import java.util.Map;

/**
 * Created by mika on 2017. 1. 16..
 */
public class User implements PersonEntity, GuestEntity, Guest {
  private String channelId;
  private String id;
  private String name;
  private String mobileNumber;
  private String avatarUrl;
  private Object meta;
  private Boolean named;
  private String locale;
  private String country;
  private String city;
  private String lastPageViewId;
  private Long pageViewsCount;
  private Long visitsCount;
  private Long createdAt;
  private Long updatedAt;
  private Long version;
  private String initial;
  private String color;
  private Map<String, Object> profile;
  private int alert;

  public String getId() {
    return id;
  }

  public String getName() {
    return name;
  }

  @Override
  public String getPersonType() {
    return this.getClass().getSimpleName();
  }

  @Override
  public int getBackgroundColor() {
    try {
      return Color.parseColor(color);
    } catch (Exception ex) {
    }
    return Color.BLACK;
  }

  @Override
  public int getTextColor() {
    return Color.WHITE;
  }

  @Override
  public String getAvatarUrl() {
    return avatarUrl;
  }

  @Override
  public String getInitial() {
    return initial;
  }

  @Override
  public boolean isHost() {
    return false;
  }

  public String getMobileNumber() {
    return mobileNumber;
  }

  public final static String CLASSNAME = "User";

  public Boolean isNamed() {
    return named;
  }

  public int getAlert() {
    return alert;
  }

  public Map<String, Object> getProfile() {
    return profile;
  }

  @Override
  public Object getProfileValue(String key) {
    if (profile != null) {
      return profile.get(key);
    } else {
      return null;
    }
  }
}
